@@ -4,18 +4,21 @@ and then calls cli.parse().
 """
 import sys
 
-from . import misc
-from . import cli
+import nodevers.shared as shared
+import nodevers.cli as cli
 
-if not misc.valid_nodevers_prefix(misc.get_nodevers_prefix()):
+if not shared.valid_nodevers_prefix(shared.get_nodevers_prefix()):
     try:
-        misc.mknodevers_prefix(misc.get_nodevers_prefix())
+        shared.mknodevers_prefix(shared.get_nodevers_prefix())
     except IOError:
         sys.stderr.write("Error: failed to create the nodevers directory")
         sys.exit(3)
 
 def main(argv):
-    cli.parse(argv[1:])
+    try:
+        cli.parse(argv[1:])
+    except KeyboardInterrupt:
+        sys.exit(1)
 
 if __name__ == "__main__":
     main(sys.argv)
