@@ -15,6 +15,7 @@ __helpstr__ = """Usage: nodevers install <version> [options]
   Options:
       -h/--help         Print this text
       --buildargs       These will be passed to Node's configure script
+      -l/--list         Display all installable versions
 
 """
 
@@ -25,29 +26,26 @@ def install(ver, build_args):
     It also handles exceptions.
     """
     if shared.version_exists(ver):
-        sys.stderr.write("Error: %s is already installed\n" % ver)
+        sys.stderr.write("Error: already installed: %s\n" % ver)
         sys.exit(1)
-    elif not shared.valid_version_string(ver):
-        sys.stderr.write("Error: %s doesn't look like a valid version\n" % ver)
-        sys.exit(2)
     try:
-        node = install_helper.NodeInstaller(ver,
+        nodesrc = install_helper.NodeSourceInstaller(ver,
                 shared.get_version_dir(ver), build_args)
         sys.stdout.write("Downloading...\n")
-        node.download_source()
+        nodesrc.download()
         sys.stdout.write("Extracting...\n")
-        node.extract_source()
+        nodesrc.extract()
         sys.stdout.write("Patching...\n")
         if len(shared.get_patches_list(ver)) == 0:
             sys.stdout.write("No patches found.\n")
         else:
-            node.patch()
+            nodesrc.patch()
         sys.stdout.write("Configuring...\n")
-        node.configure()
+        nodesrc.configure()
         sys.stdout.write("Building...\n")
-        node.make()
+        nodesrc.make()
         sys.stdout.write("Installing...\n")
-        node.make_install()
+        nodesrc.make_install()
     except StandardError:
         err = sys.exc_info()[1]
         sys.stderr.write("Error: %s\n" % str(err))
@@ -55,7 +53,7 @@ def install(ver, build_args):
     finally:
         sys.stdout.write("Cleaning up...\n")
         try:
-            node.cleanup()
+            nodesrc.cleanup()
         except StandardError:
             pass
 
@@ -66,18 +64,23 @@ def parse(args):
     """
     if len(args) == 0 or args[0] in ("-h", "--help"):
         shared.help_func(__helpstr__)
+    elif args[0] in ("-l", "--list"):
+        try:
+            for v in shared.get_remote_versions_list():
+                sys.stdout.write("%s\n" % v)
+        except StandardError:
+            err = sys.exc_info()[1]
+            sys.stderr.write("Error: %s\n" % str(err))
+            sys.exit(2)
     else:
         build_args = ""
         try:
-            optlist, arglist = getopt.getopt(args[1:], "h", ["help",
-                "buildargs="])
+            optlist, arglist = getopt.getopt(args[1:], "", ["buildargs="])
         except getopt.error:
             err = sys.exc_info()[1]
             sys.stderr.write("Error: %s\n" % str(err))
             sys.exit(-1)
         for option, value in optlist:
-            if option in ("-h", "--help"):
-                shared.help_func(__helpstr__)
-            elif option in ("--buildargs"):
+            if option in ("--buildargs"):
                 build_args = value
         install(args[0], build_args)
