@@ -9,6 +9,7 @@ import os
 import sys
 import tarfile
 import shutil
+import re
 from subprocess import call
 
 import nodevers.shared as shared
@@ -26,8 +27,6 @@ else:
     from urllib2 import urlopen
     from urllib import urlretrieve
 
-
-
 class BuildError(StandardError):
     """
     Will be thrown when ./configure, make
@@ -35,8 +34,7 @@ class BuildError(StandardError):
     """
     pass
 
-
-class NodeInstaller(object):
+class NodeSourceInstaller(object):
     """
     This will install Node.
     """
@@ -44,14 +42,10 @@ class NodeInstaller(object):
         self.ver = ver
         self.install_path = install_path
         self.build_args = build_args
+        if not shared.valid_version_string(self.ver):
+            raise shared.NoSuchVersionError("unknown version: %s" % self.ver)
         self.url = "http://nodejs.org/dist/v%s/node-v%s.tar.gz" % (self.ver,
                 self.ver)
-        try:
-            urlopen(self.url)
-        except HTTPError:
-            raise shared.NoSuchVersionError("cannot download node-v%s.tar.gz" % self.ver)
-        except URLError:
-            raise IOError("make sure you are connected to the Internet")
         self.tmpdir = shared.get_tmp_dir()
         try:
             logfile_path = os.path.join(os.path.join(shared.get_nodevers_prefix(), "log"))
@@ -59,7 +53,7 @@ class NodeInstaller(object):
         except IOError:
             self.logfile = open(os.devnull, 'w')
 
-    def download_source(self):
+    def download(self):
         """
         This will download the source packages.
         """
@@ -71,10 +65,10 @@ class NodeInstaller(object):
             try:
                 urlretrieve(self.url, self.package)
             except IOError:
-                raise IOError("make sure you are connected to the Internet")
+                raise IOError("cannot download: %s" % self.package)
             except ContentTooShortError:
-                raise IOError("the download was interrupted")
-    def extract_source(self):
+                raise ContentTooShortError("the download was interrupted")
+    def extract(self):
         """
         This method will extract the source files from
         download package.
@@ -84,7 +78,7 @@ class NodeInstaller(object):
             extract = tarfile.open(self.package, "r|gz")
         except tarfile.ReadError:
             os.remove(self.package)
-            raise IOError("%s is corrupted" % self.package)
+            raise tarfile.ReadError("corrupted package: %s" % self.package)
         extract.extractall()
         extract.close()
         os.chdir("node-v%s" % self.ver)
@@ -110,10 +104,15 @@ class NodeInstaller(object):
         """
         Configure Node.
         """
-        exit_code = call([shared.python(), "configure",
-            "--prefix=%s" % self.install_path,
-            "%s" % self.build_args],
-            stdout=self.logfile, stderr=self.logfile)
+        if re.match("0\.[0-6]\.\d+", self.ver):
+            exit_code = call(["./configure", "--prefix=%s" % self.install_path,
+                    "%s" % self.build_args],
+                    stdout=self.logfile, stderr=self.logfile)
+        else:
+            exit_code = call([shared.python(), "configure",
+                "--prefix=%s" % self.install_path,
+                "%s" % self.build_args],
+                stdout=self.logfile, stderr=self.logfile)
         if exit_code is not 0:
             raise BuildError("configure has failed")
     def make(self):
