@@ -16,19 +16,8 @@ import re
 import subprocess
 import sys
 import getopt
-from . import cli
+import nodevers.shared as shared
 
-def current_version():
-    """
-    Try to get the current version.
-    """
-    # We'll let parse() handle the exceptions.
-    process = subprocess.Popen(["node", "-v"], stdout=subprocess.PIPE)
-    node_output = process.stdout.read()
-    regex = "v(\d+\.\d+\.\d+)"
-    match = re.match(regex, node_output)
-    ver = match.group(1)
-    return ver
 
 def parse(args):
     """
@@ -37,10 +26,10 @@ def parse(args):
     """
     if len(args) == 0:
         try:
-            ver = current_version()
+            ver = shared.current_version()
             sys.stdout.write("%s\n" % ver)
         except OSError:
-            sys.stderr.write("There is no currently active Node.\n")
+            sys.stderr.write("Error: there is no currently active Node\n")
     else:
         try:
             optlist, arglist = getopt.getopt(args, "h", ["help"])
@@ -50,4 +39,4 @@ def parse(args):
             sys.exit(-1)
         for option, value in optlist:
             if option in ("-h", "--help"):
-                cli.help_func(__helpstr__)
+                shared.help_func(__helpstr__)
